# Welcome to Data to Science Python (d2spy)

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<p align="center">
  <img
    src="https://py.d2s.org/assets/d2s-logo.png"
    alt="Data to Science logo"
    width="128"
  >
</p>

D2spy is a Python package for interacting with Data to Science instances.

## Features

- Sign in to your Data to Science instance
- Access your projects, flights, and data products
- Create new projects and flights
- Upload data products to flights

## Documentation

- [Homepage](https://py.d2s.org/)
- [Guides](https://py.d2s.org/guides)
- [API Reference](https://py.d2s.org/api_client/)
